#[repr(C)]pub struct Solution {Show 17 fields
pub public_key_hash: Blake3Hash,
pub shard_commitment: SolutionShardCommitment,
pub piece_local_segment_index: LocalSegmentIndex,
pub piece_super_segment_index: SuperSegmentIndex,
pub segment_root: SegmentRoot,
pub segment_proof: SegmentProof,
pub record_root: RecordRoot,
pub record_proof: RecordProof,
pub chunk: RecordChunk,
pub chunk_proof: ChunkProof,
pub proof_of_space: PosProof,
pub history_size: HistorySize,
pub sector_index: SectorIndex,
pub piece_offset: PieceOffset,
pub segment_position: SegmentPosition,
pub piece_shard_index: ShardIndex,
pub padding: [u8; 4],
}Expand description
Farmer solution for slot challenge.
Fields
public_key_hash: Blake3HashPublic key of the farmer that created the solution
shard_commitment: SolutionShardCommitmentFarmer’s shard commitment
piece_local_segment_index: LocalSegmentIndexLocal segment index of the piece
piece_super_segment_index: SuperSegmentIndexSuper segment index
segment_root: SegmentRootSegment root
segment_proof: SegmentProofSegment proof
record_root: RecordRootRecord root that can use used to verify that the piece was included in blockchain history
record_proof: RecordProofProof that the record (root) belongs to a segment
chunk: RecordChunkChunk at the below piece offset
chunk_proof: ChunkProofProof for the above chunk
proof_of_space: PosProofProof of space for piece offset
history_size: HistorySizeSize of the blockchain history at the time of sector creation
sector_index: SectorIndexIndex of the sector where the solution was found
piece_offset: PieceOffsetPieces offset within sector
segment_position: SegmentPositionPosition of the segment in the super segment
piece_shard_index: ShardIndexShard index on which the piece was archived
padding: [u8; 4]Padding for data structure alignment
Implementations
Sourceimpl Solution
impl Solution
Sourcepub fn genesis_solution() -> Self
pub fn genesis_solution() -> Self
Fake solution for the genesis block
Sourcepub fn verify_full<PotVerifier>(
&self,
slot: SlotNumber,
params: &SolutionVerifyFullParams,
) -> Result<(), SolutionVerifyError>where
PotVerifier: SolutionPotVerifier,
pub fn verify_full<PotVerifier>(
&self,
slot: SlotNumber,
params: &SolutionVerifyFullParams,
) -> Result<(), SolutionVerifyError>where
PotVerifier: SolutionPotVerifier,
Check solution validity
Sourcepub fn verify_stateless<PotVerifier>(
&self,
slot: SlotNumber,
params: &SolutionVerifyStatelessParams,
) -> Result<(), SolutionVerifyError>where
PotVerifier: SolutionPotVerifier,
pub fn verify_stateless<PotVerifier>(
&self,
slot: SlotNumber,
params: &SolutionVerifyStatelessParams,
) -> Result<(), SolutionVerifyError>where
PotVerifier: SolutionPotVerifier,
Stateless solution verification.
Checks most things, except checking that the piece belongs to the global history.
For piece verification use Self::verify_piece() or call Self::verify_full() for more
efficient verification of both at once.
Sourcepub fn verify_piece(
&self,
piece_check_params: &SolutionVerifyPieceParams,
) -> Result<(), SolutionVerifyError>
pub fn verify_piece( &self, piece_check_params: &SolutionVerifyPieceParams, ) -> Result<(), SolutionVerifyError>
Verify the piece details of the solution