pub struct SolutionVerifyPieceParams {
pub max_pieces_in_sector: u16,
pub super_segment_root: SuperSegmentRoot,
pub num_segments: u32,
pub recent_segments: HistorySize,
pub recent_history_fraction: (HistorySize, HistorySize),
pub min_sector_lifetime: HistorySize,
pub current_history_size: HistorySize,
pub sector_expiration_check_segment_root: Option<SegmentRoot>,
}Expand description
Parameters for checking piece validity used in a solution
Fields
max_pieces_in_sector: u16How many pieces one sector is supposed to contain (max)
super_segment_root: SuperSegmentRootSuper segment root of the segment to which piece belongs
num_segments: u32Number of segments in the super segment
recent_segments: HistorySizeNumber of latest archived segments that are considered “recent history”
recent_history_fraction: (HistorySize, HistorySize)Fraction of pieces from the “recent history” (recent_segments) in each sector
min_sector_lifetime: HistorySizeMinimum lifetime of a plotted sector, measured in archived segments
current_history_size: HistorySizeCurrent size of the history
sector_expiration_check_segment_root: Option<SegmentRoot>Segment root at min_sector_lifetime from sector creation (if exists)