pub struct SolutionVerifyStatelessParams {
pub shard_index: ShardIndex,
pub proof_of_time: PotOutput,
pub solution_range: SolutionRange,
pub shard_membership_entropy: ShardMembershipEntropy,
pub num_shards: NumShards,
}Expand description
Parameters for stateless solution verification.
These only include the information already contained in the block itself, meaning verification of different blocks can be done concurrently.
Fields
shard_index: ShardIndexShard for which the solution is built
proof_of_time: PotOutputProof of time for which solution is built
solution_range: SolutionRangeSolution range
shard_membership_entropy: ShardMembershipEntropyShard membership entropy
num_shards: NumShardsThe number of shards in the network